@@ -1,7 +1,7 @@
 package Logfile::Tail::Switch;
 
 our $DATE = '2017-06-09'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,40 +10,49 @@ use warnings;
 use Time::HiRes 'time';
 
 sub new {
-    my ($class, $glob, $opts) = @_;
-
-    defined($glob) or die "Please specify glob";
-    $opts //= {};
-
-    $opts->{check_freq} //= 5;
+    my ($class, %args) = @_;
 
     my $self = {
-        glob => $glob,
-        opts => $opts,
-        _cur_file => undef,
-        _cur_fh   => undef,
-        _pending  => {},
+        _cur_file  => {},
+        _cur_fh    => {},
+        _pending   => {},
+        check_freq => 2,
+        tail_new   => 0,
     };
 
+    if (defined(my $globs = delete $args{globs})) {
+        ref($globs) eq 'ARRAY' or die "globs must be arrayref";
+        $self->{globs} = $globs;
+    } else {
+        die "Please specify globs";
+    }
+    if (defined(my $check_freq = delete $args{check_freq})) {
+        $self->{check_freq} = $check_freq;
+    }
+    if (defined(my $tail_new = delete $args{tail_new})) {
+        $self->{tail_new} = $tail_new;
+    }
+    die "Unknown arguments: ".join(", ", keys %args) if keys %args;
+
     bless $self, $class;
 }
 
 sub _switch {
-    my ($self, $filename, $seek_end) = @_;
+    my ($self, $glob, $filename, $seek_end) = @_;
 
     #say "D: opening $filename";
-    $self->{_cur_file} = $filename;
+    $self->{_cur_file}{$glob} = $filename;
     open my $fh, "<", $filename or die "Can't open $filename: $!";
     seek $fh, 0, 2 if $seek_end;
-    $self->{_cur_fh} = $fh;
+    $self->{_cur_fh}{$glob} = $fh;
 }
 
 sub _getline {
-    my $self = shift;
+    my ($self, $fh) = @_;
 
-    my $fh = $self->{_cur_fh};
     my $size = -s $fh;
     my $pos = tell $fh;
+    #say "D:size=<$size>, pos=<$pos>";
     if ($pos == $size) {
         # we are still at the end of file, return empty string
         return '';
@@ -65,37 +74,48 @@ sub getline {
   CHECK_NEWER_FILES:
     {
         last if $self->{_last_check_time} &&
-            $self->{_last_check_time} >= $now - $self->{opts}{check_freq};
-        #say "D: checking for newer file";
-        my @files = sort glob($self->{glob});
-        #say "D: files matching glob: ".join(", ", @files);
+            $self->{_last_check_time} >= $now - $self->{check_freq};
         $self->{_last_check_time} = $now;
-        last unless @files;
-        if (defined $self->{_cur_fh}) {
-            for (@files) {
-                # there is a newer file than the current one, add to the pending
-                # list of files to be read after the current one
-                #say "D: there is a newer file: $_";
-                $self->{_pending}{$_} = 1
-                    if $_ gt $self->{_cur_file};
+        #say "D: checking for newer file";
+        for my $glob (@{ $self->{globs} }) {
+            my @files = sort glob($glob);
+            #say "D: files matching glob: ".join(", ", @files);
+            unless (@files) {
+                warn "No files matched '$glob'";
+                next;
+            }
+            if (defined $self->{_cur_fh}{$glob}) {
+                for (@files) {
+                    # there is a newer file than the current one, add to the
+                    # pending list of files to be read after the current one say
+                    if ($_ gt $self->{_cur_file}{$glob}) {
+                        #say "D: there is a newer file: $_";
+                        $self->{_pending}{$glob}{$_} = 1;
+                    }
+                }
+            } else {
+                # this is our first time, pick the newest file in the pattern
+                # and tail it.
+                $self->_switch($glob, $files[-1], 1);
             }
-        } else {
-            # this is our first time, pick the newest file in the pattern and
-            # tail it.
-            $self->_switch($files[-1], 1);
         }
     }
 
-    # we don't have any matching files
-    return '' unless $self->{_cur_fh};
-
-    my $line = $self->_getline;
-    if (!length($line) && keys %{$self->{_pending}}) {
-        # switch to a newer named file
-        my @files = sort keys %{$self->{_pending}};
-        $self->_switch($files[0]);
-        delete $self->{_pending}{$files[0]};
-        $line = $self->_getline;
+    my $line = '';
+    for my $glob (@{ $self->{globs} }) {
+        my $fh = $self->{_cur_fh}{$glob};
+        next unless $fh;
+        $line = $self->_getline($fh);
+        if (length $line) {
+            last;
+        } elsif (keys %{$self->{_pending}{$glob}}) {
+            # switch to a newer named file
+            my @files = sort keys %{$self->{_pending}{$glob}};
+            $self->_switch($glob, $files[0], $self->{tail_new});
+            delete $self->{_pending}{$glob}{$files[0]};
+            $line = $self->_getline($self->{_cur_fh}{$glob});
+            last if length $line;
+        }
     }
     $line;
 }
@@ -115,14 +135,18 @@ Logfile::Tail::Switch - Tail a file, but switch when another file with newer nam
 
 =head1 VERSION
 
-This document describes version 0.002 of Logfile::Tail::Switch (from Perl distribution Logfile-Tail-Switch), released on 2017-06-09.
+This document describes version 0.003 of Logfile::Tail::Switch (from Perl distribution Logfile-Tail-Switch), released on 2017-06-09.
 
 =head1 SYNOPSIS
 
  use Logfile::Tail::Switch;
  use Time::HiRes 'sleep'; # for subsecond sleep
 
- my $tail = Logfile::Tail::Switch->new("/s/example.com/syslog/http_access.*.log");
+ my $tail = Logfile::Tail::Switch->new(
+     globs => ["/s/example.com/syslog/http_access.*.log"],
+     # check_freq => 2,
+     # tail_new => 0,
+ );
 
  # tail
  while (1) {
@@ -150,7 +174,7 @@ When using this class, you specify a glob pattern of files, e.g.
 C</s/example.com/syslog/http_access.*.log>. Then you call the C<getline> method.
 
 This class will first select the newest file (via asciibetical sorting) from the
-glob pattern and tail it. Then, periodically (by default at most every 5
+glob pattern and tail it. Then, periodically (by default at most every 2
 seconds) the glob pattern will be checked again. If there is one or more newer
 files, they will be read in full and then tail-ed, until an even newer file
 comes along. For example, this is the list of files in C</s/example.com/syslog>
@@ -169,15 +193,24 @@ next day, that file will be read then tail'ed. And so on.
 
 =head1 METHODS
 
-=head2 Logfile::Tail::Switch->new($glob [, \%opts ]) => obj
+=head2 Logfile::Tail::Switch->new(%args) => obj
 
 Constructor.
 
-Known options:
+Known arguments:
 
 =over
 
-=item * check_freq => posint (default: 5)
+=item * globs => array
+
+Glob patterns.
+
+=item * check_freq => posint (default: 2)
+
+=item * tail_new => bool
+
+If set to true, then new file that appears will be tail'ed instead of read from
+the beginning.
 
 =back
 
